arkdb

package module
v0.0.0-...-90a1d44 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 15, 2019 License: Apache-2.0 Imports: 2 Imported by: 0

README

arkdb

Build Status codecov

arkdb is a research project. It is an attempt to make a small and simple relational SQL database that is embedded and distributed naturally using raft. It should allow distributed applications to be easily built on top of it.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type DB

type DB interface {
	Start() error
}

func NewDB

func NewDB(options *Options) DB

type Options

type Options struct {
	Directory    string
	Peers        []string
	EnableSingle bool
	Transport    transport.Transport
}

Directories

Path Synopsis
internal
pkg

Jump to